@@ -15,11 +15,12 @@ import re
 from astro_ghost.PS1QueryFunctions import getcolorim, get_hosts
 from astro_ghost.hostMatching import build_ML_df
 from astro_ghost.NEDQueryFunctions import getNEDInfo
+from astropy.coordinates import Angle
 from astro_ghost.gradientAscent import gradientAscent
 from astro_ghost.starSeparation import separateStars_STRM
 from astro_ghost.sourceCleaning import clean_dict, removePS1Duplicates, getColors, makeCuts
 from astro_ghost.stellarLocus import calc_7DCD
-from astro_ghost.DLR import chooseByDLR
+from astro_ghost.DLR import calc_DLR, chooseByDLR
 import requests
 import pickle
 import os
@@ -550,7 +551,7 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle'):
         print("ERROR: Found no hosts in cone search during manual association!")
         return None
 
-    cuts = ["n", "quality", "coords", "primary", "best", "duplicate"]
+    cuts = ["n", "quality", "coords", "duplicate"]
 
     transient_dict = pickle.load(open(path+'/dictionaries/'+fn_Dict, "rb"))
     transient_dict = {k.replace(' ', ''): v for k, v in transient_dict.items()}
@@ -651,6 +652,33 @@ def findNewHosts(snName, snCoord, snClass, verbose=0, starcut='gentle'):
     if verbose:
         print("Saving table of hosts to %s."%(path+"tables/FinalAssociationTable.csv"))
 
+    # re-calculate dist and dist/DLR values for the SN matched by gradient ascent
+    #DLR = []
+    #dist = []
+    for idx, row in host_DF.iterrows():
+        if row.dist != row.dist:
+            try:
+                theta = np.nan
+                #get source
+                table1 = host_DF.iloc[[idx]]
+                tempDist, R = calc_DLR(Angle(table1['TransientRA'].values[0]*u.deg),Angle(table1['TransientDEC'].values[0]*u.deg),table1['raMean'], table1['decMean'], np.float64(table1['rKronRad']), np.float64(table1['rKronRad']), table1, 'r')
+                #DLR.append(R)
+                #dist.append(tempDist[0])
+                host_DF.loc[idx, 'dist'] = tempDist[0]
+                host_DF.loc[idx, 'dist/DLR'] = R
+            except:
+                #DLR.append(1.e10)
+                #dist.append(np.nan)
+                host_DF.loc[idx, 'dist'] = np.nan
+                host_DF.loc[idx, 'dist/DLR'] = 1.e10
+    print(host_DF['dist'])
+
+    #DLR = np.array(DLR)
+    #dist = np.array(dist)
+
+    #host_DF["dist"] = dist
+    #host_DF["dist/DLR"] = DLR
+
     host_DF.to_csv(path+"FinalAssociationTable.csv", index=False)
 
     #hSpecPath = path+"/hostSpectra/"
